@@ -58,7 +58,7 @@ class StreamClient(object):
             self.base_url = base_url
         elif location is not None:
             self.base_url = 'https://%s-api.getstream.io/api/' % location
-            
+
         self.base_analytics_url = 'https://analytics.getstream.io/analytics/'
 
         self.session = requests.Session()
@@ -167,6 +167,7 @@ class StreamClient(object):
                           params=default_params, timeout=self.timeout)
         logger.debug('stream api call %s, headers %s data %s',
                      response.url, headers, data)
+        import pdb; pdb.set_trace()
         return self._parse_response(response)
 
     def raise_exception(self, result, status_code):
@@ -180,8 +181,11 @@ class StreamClient(object):
 
         def errors_from_fields(exception_fields):
             result = []
+            if not isinstance(exception_fields, dict):
+                return exception_fields
+
             for field, errors in exception_fields.items():
-                errors.append('Field "%s" errors: %s' % (field, repr(errors)))
+                result.append('Field "%s" errors: %s' % (field, repr(errors)))
             return result
 
         if result is not None:
@@ -268,7 +272,7 @@ class StreamClient(object):
         Update a single activity
         '''
         return self.update_activities([activity])
-        
+
     def create_redirect_url(self, target_url, user_id, events):
         '''
         Creates a redirect url for tracking the given events in the context
